summaryrefslogtreecommitdiff
path: root/indra/newview/llviewerdisplayname.cpp
diff options
context:
space:
mode:
authorsimon <none@none>2013-04-11 16:04:21 -0700
committersimon <none@none>2013-04-11 16:04:21 -0700
commitc7bab8ab8b25249d1f8f87746b50fce4820f542a (patch)
treef10f811e0a03002b4c545eb5c51f99d7c5b83a5b /indra/newview/llviewerdisplayname.cpp
parenta976f5c217ce97c70a7e151b9a490e6a6ebf1396 (diff)
parent460c81070e5fa1c51ce7e186a9ecb8c5f1c995e1 (diff)
Merge
Diffstat (limited to 'indra/newview/llviewerdisplayname.cpp')
-rw-r--r--indra/newview/llviewerdisplayname.cpp4
1 files changed, 3 insertions, 1 deletions
diff --git a/indra/newview/llviewerdisplayname.cpp b/indra/newview/llviewerdisplayname.cpp
index 6bd5631df6..f81206ffec 100644
--- a/indra/newview/llviewerdisplayname.cpp
+++ b/indra/newview/llviewerdisplayname.cpp
@@ -60,8 +60,10 @@ class LLSetDisplayNameResponder : public LLHTTPClient::Responder
{
public:
// only care about errors
/*virtual*/ void error(U32 status, const std::string& reason)
{
+ llwarns << "LLSetDisplayNameResponder error [status:"
+ << status << "]: " << content << llendl;
LLViewerDisplayName::sSetDisplayNameSignal(false, "", LLSD());
LLViewerDisplayName::sSetDisplayNameSignal.disconnect_all_slots();
}
@@ -60,8 +60,10 @@ class LLSetDisplayNameResponder : public LLHTTPClient::Responder
public:
// only care about errors
- /*virtual*/ void error(U32 status, const std::string& reason)
+ /*virtual*/ void errorWithContent(U32 status, const std::string& reason, const LLSD& content)
{